@@ -12,3 +12,8 @@ class RadioSelectSurvey(forms.RadioSelect):
 class DateSurvey(forms.DateTimeInput):
     template_name = 'djf_surveys/widgets/datepicker.html'
 
+
+class RatingSurvey(forms.HiddenInput):
+    template_name = 'djf_surveys/widgets/star_rating.html'
+
+
